mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
* [PATCH]: drivers/connector/cn_proc.c typos
@ 2005-11-30  8:52 David S. Miller
  0 siblings, 0 replies; only message in thread
From: David S. Miller @ 2005-11-30  8:52 UTC (permalink / raw)
  To: linux-kernel


The parameter to put_cpu_var() is unreferenced by the implementation,
and the compiler doesn't try to comprehend comments, so this wouldn't
cause any problem, but if bugged me enough to post a fix :-)

Signed-off-by: David S. Miller <davem@davemloft.net>

diff --git a/drivers/connector/cn_proc.c b/drivers/connector/cn_proc.c
index fcdf0ff..7f59f79 100644
--- a/drivers/connector/cn_proc.c
+++ b/drivers/connector/cn_proc.c
@@ -34,14 +34,14 @@
 static atomic_t proc_event_num_listeners = ATOMIC_INIT(0);
 static struct cb_id cn_proc_event_id = { CN_IDX_PROC, CN_VAL_PROC };
 
 /* proc_counts is used as the sequence number of the netlink message */
 static DEFINE_PER_CPU(__u32, proc_event_counts) = { 0 };
 
 static inline void get_seq(__u32 *ts, int *cpu)
 {
 	*ts = get_cpu_var(proc_event_counts)++;
 	*cpu = smp_processor_id();
-	put_cpu_var(proc_counts);
+	put_cpu_var(proc_event_counts);
 }
 
 void proc_fork_connector(struct task_struct *task)

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2005-11-30  8:52 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -34,14 +34,14 @@
 static struct cb_id cn_proc_event_id = { CN_IDX_PROC, CN_VAL_PROC };
 
-/* proc_counts is used as the sequence number of the netlink message */
+/* proc_event_counts is used as the sequence number of the netlink message */
 static DEFINE_PER_CPU(__u32, proc_event_counts) = { 0 };
 
2005-11-30  8:52 [PATCH]: drivers/connector/cn_proc.c typos David S. Miller

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

all inboxes | Powered by JetHome®